@@ -19,7 +19,7 @@ from python_inspector.utils import write_output_in_file
 
 TRACE = False
 
-__version__ = "0.10.0"
+__version__ = "0.11.0"
 
 DEFAULT_PYTHON_VERSION = "38"
 PYPI_SIMPLE_URL = "https://pypi.org/simple"
@@ -173,6 +173,9 @@ def print_version(ctx, param, value):
     callback=print_version,
     help="Show the version and exit.",
 )
+@click.option(
+    "--ignore-errors", is_flag=True, default=False, help="Ignore errors and continue execution."
+)
 @click.help_option("-h", "--help")
 @click.option(
     "--generic-paths",
@@ -199,6 +202,7 @@ def resolve_dependencies(
     prefer_source=False,
     verbose=TRACE,
     generic_paths=False,
+    ignore_errors=False,
 ):
     """
     Resolve the dependencies for the package requirements listed in one or
@@ -266,6 +270,7 @@ def resolve_dependencies(
             analyze_setup_py_insecurely=analyze_setup_py_insecurely,
             printer=click.secho,
             prefer_source=prefer_source,
+            ignore_errors=ignore_errors,
             generic_paths=generic_paths,
         )
 
