@@ -42,6 +42,27 @@ def test_cli_with_default_urls():
     )
 
 
+@pytest.mark.online
+def test_cli_with_requirements_and_ignore_errors():
+    requirements_file = test_env.get_test_loc("error-requirements.txt")
+    expected_file = test_env.get_test_loc(
+        "example-requirements-ignore-errors-expected.json", must_exist=False
+    )
+    extra_options = [
+        "--ignore-errors",
+        "--operating-system",
+        "linux",
+        "--python-version",
+        "310",
+    ]
+    check_requirements_resolution(
+        requirements_file=requirements_file,
+        expected_file=expected_file,
+        extra_options=extra_options,
+        regen=REGEN_TEST_FIXTURES,
+    )
+
+
 @pytest.mark.online
 def test_pdt_output():
     requirements_file = test_env.get_test_loc("pdt-requirements.txt")
@@ -373,7 +394,7 @@ def test_passing_of_json_pdt_and_json_flags():
 def test_version_option():
     options = ["--version"]
     result = run_cli(options=options)
-    assert "0.10.0" in result.output
+    assert "0.11.0" in result.output
 
 
 def test_passing_of_netrc_file_that_does_not_exist():
