@@ -50,8 +50,8 @@ def test_get_resolved_dependencies_with_flask_and_python_310():
         "pkg:pypi/click@8.1.7",
         "pkg:pypi/flask@2.1.2",
         "pkg:pypi/itsdangerous@2.1.2",
-        "pkg:pypi/jinja2@3.1.2",
-        "pkg:pypi/markupsafe@2.1.3",
+        "pkg:pypi/jinja2@3.1.3",
+        "pkg:pypi/markupsafe@2.1.5",
         "pkg:pypi/werkzeug@3.0.1",
     ]
 
@@ -74,8 +74,8 @@ def test_get_resolved_dependencies_with_flask_and_python_310_windows():
         "pkg:pypi/colorama@0.4.6",
         "pkg:pypi/flask@2.1.2",
         "pkg:pypi/itsdangerous@2.1.2",
-        "pkg:pypi/jinja2@3.1.2",
-        "pkg:pypi/markupsafe@2.1.3",
+        "pkg:pypi/jinja2@3.1.3",
+        "pkg:pypi/markupsafe@2.1.5",
         "pkg:pypi/werkzeug@3.0.1",
     ]
 
@@ -123,10 +123,10 @@ def test_get_resolved_dependencies_with_tilde_requirement_using_json_api():
     assert plist == [
         "pkg:pypi/click@8.1.7",
         "pkg:pypi/flask@2.1.3",
-        "pkg:pypi/importlib-metadata@6.8.0",
+        "pkg:pypi/importlib-metadata@7.0.1",
         "pkg:pypi/itsdangerous@2.1.2",
-        "pkg:pypi/jinja2@3.1.2",
-        "pkg:pypi/markupsafe@2.1.3",
+        "pkg:pypi/jinja2@3.1.3",
+        "pkg:pypi/markupsafe@2.1.5",
         "pkg:pypi/werkzeug@3.0.1",
         "pkg:pypi/zipp@3.17.0",
     ]
@@ -152,12 +152,12 @@ def test_get_resolved_dependencies_for_version_containing_local_version_identifi
     assert plist == [
         "pkg:pypi/filelock@3.9.0",
         "pkg:pypi/jinja2@3.1.2",
-        "pkg:pypi/markupsafe@2.1.2",
+        "pkg:pypi/markupsafe@2.1.3",
         "pkg:pypi/mpmath@1.3.0",
-        "pkg:pypi/networkx@3.0",
+        "pkg:pypi/networkx@3.2.1",
         "pkg:pypi/sympy@1.12",
         "pkg:pypi/torch@2.0.0%2Bcpu",
-        "pkg:pypi/typing-extensions@4.4.0",
+        "pkg:pypi/typing-extensions@4.8.0",
     ]
 
 
@@ -178,11 +178,11 @@ def test_without_supported_wheels():
     assert plist == [
         "pkg:pypi/autobahn@22.3.2",
         "pkg:pypi/cffi@1.16.0",
-        "pkg:pypi/cryptography@41.0.5",
+        "pkg:pypi/cryptography@42.0.2",
         "pkg:pypi/hyperlink@21.0.0",
-        "pkg:pypi/idna@3.4",
+        "pkg:pypi/idna@3.6",
         "pkg:pypi/pycparser@2.21",
-        "pkg:pypi/setuptools@68.2.2",
+        "pkg:pypi/setuptools@69.0.3",
         "pkg:pypi/txaio@23.1.1",
     ]
 
